sub init()
    print "INIT: MoviesGridPanel"
    
    m.top.panelSize = "medium"
    m.top.focusable = true
    m.top.hasNextPanel = true
    m.top.leftOnly = false
    m.top.goBackCount = 1
    
    m.top.createNextPanelOnItemFocus = false
    m.top.selectButtonMovesPanelForward = false

    m.top.grid = m.top.FindNode("MoviesGrid")
    
    m.top.leftLabel.font = m.global.fonts.regular18
    m.top.leftLabel.color = m.global.color.highlight
    m.top.rightLabel.font = m.global.fonts.regular18
    m.top.rightLabel.color = m.global.color.text2
    
    m.top.sortID = 0
    m.sorting = [
        {id:0, title: "Newest", sortString: "&sort=year&sortType=desc" },
        {id:1, title: "Best", sortString: "&sort=rating_kinopoisk&sortType=desc" },
        {id:2, title: "A - Z", sortString: "&sort=title&sortType=asc" },
        {id:3, title: "Z - A", sortString: "&sort=title&sortType=desc" },
    ]
end sub
'******************************************************
sub GetMovies()
    if m.top.genreId < 0
        print "Get Movies: Incorrect genre ID = ";m.top.genreId
        SetEmptyContent()
        return
    end if

    print "...Get Movies"
    m.global.loading = true
    SetLoadingContent()
    m.request = createObject("roSGNode","GetRequest")
    if m.global.movieCategoryID <> invalid and m.global.movieCategoryID > 0
        m.request.uri = m.global.apipath+m.global.apiname+m.global.vodpath+"/vod/ws/Search?sessionId="+ m.global.sessionId+"&categoryId="+m.global.movieCategoryID.tostr()+"&genreId="+m.top.genreId.tostr()+m.sorting[m.top.sortID].sortString
    else
        m.request.uri = m.global.apipath+m.global.apiname+m.global.vodpath+"/vod/ws/Search?sessionId="+ m.global.sessionId+"&genreId="+m.top.genreId.tostr()+m.sorting[m.top.sortID].sortString
    end if
    m.request.observeField("content","OnMovies")
    m.request.control = "RUN"
end sub

sub OnMovies()
    print "OnMovies: "';m.request.content
    json = ParseJSON(m.request.content)
    if(json<>invalid and json.video_list<>invalid)
        movies = CreateObject("roArray", json.video_list.Count(), true)                  
        'print "________ Movies Titles __________"
        for x = 0 To json.video_list.Count()-1
            movies[x]  = json.video_list[x]
            'print movies[x].title
        End for
        'print "______________________________"
        print "OnMovies: total = ";movies.Count()
        
        if(m.global.hasField("movies"))
            m.global.movies = movies
        else
            m.global.addFields({movies: movies})
        end if
        
        UpdateMovies(movies)
    else
        print "...Movies = Invalid! Error"
        m.top.rightLabel.text = getTr("Error")
        SetEmptyContent()
    end if
end sub

sub UpdateMovies(movies)
    print "...UpdateMovies" 
    m.global.loading = false
    MoviesContent = createObject("RoSGNode","ContentNode")
    if movies<>invalid
        num = 0
        for each movie in movies
            node = MoviesContent.createChild("ContentNode")
            ' TODO save Movie ID and num            
            node.Title = movie.title
            node.Description = movie.description
            node.SDPosterUrl = movie.image.small
            node.HDPosterUrl = movie.image.big
            num++
        end for
    end if
    
    if movies<>invalid and movies.Count()>0
        'm.top.leftLabel.text = m.top.genreName
        m.top.rightLabel.text = "1 "+getTr("of")+" "+movies.Count().tostr()
        m.top.grid.content = MoviesContent
    else
        m.top.leftLabel.text = ""
        m.top.rightLabel.text = ""
        SetEmptyContent()
    end if
    
    if m.global.mainScene.MovieInfoPanel <> invalid
        m.global.mainScene.MovieInfoPanel.movieNum = m.top.grid.itemFocused
    end if
end sub
'******************************************************
sub SetLoadingContent()
    MoviesContent = createObject("RoSGNode","ContentNode")
    node = MoviesContent.createChild("ContentNode")
    'node.channelID = -1
    'node.channelNum = -1
    node.Title = getTr("Loading...")
    node.SDPosterUrl = "pkg:/images/logo_side_big.png"
    node.HDPosterUrl = "pkg:/images/logo_side_big.png"
    m.top.grid.content = MoviesContent
    m.top.rightLabel.text = getTr("Loading...")
end sub

sub SetEmptyContent()
    MoviesContent = createObject("RoSGNode","ContentNode")
    node = MoviesContent.createChild("ChannelsGridItemData")
    'node.channelID = -1
    'node.channelNum = -1
    node.Title = getTr("No movies")
    node.SDPosterUrl = "pkg:/images/logo_side_big.png"
    node.HDPosterUrl = "pkg:/images/logo_side_big.png"
    m.top.grid.content = MoviesContent
    m.top.rightLabel.text = getTr("No movies")
end sub
'******************************************************
'******************************************************
sub ChangeSorting()
    m.dialog = createObject("roSGNode","Dialog")
    m.dialog.title = getTr("Sorting")
    m.dialog.optionsDialog = true
    m.dialog.titleFont = m.global.fonts.regular20
    m.dialog.buttonGroup.textFont = m.global.fonts.regular20
    m.dialog.buttonGroup.focusedTextFont = m.global.fonts.regular20
    m.dialog.buttonGroup.focusBitmapUri = "pkg:/images/select.9.png"
    m.dialog.buttonGroup.focusFootprintBitmapUri = "pkg:/images/selected.9.png"
    
    newarray = CreateObject("roArray", m.sorting.Count(), true)
    for i=0 to m.sorting.Count()-1
        newarray.Push(getTr(m.sorting[i].title))
    end for
    m.dialog.buttons = newarray
    m.dialog.focusButton = m.top.sortID
    m.dialog.observeField("buttonSelected","OnChangeSorting")
    
    m.global.mainScene.dialog = m.dialog
end sub

sub OnChangeSorting()
    if m.dialog <> invalid
        print "... On Change Sorting: ";m.dialog.buttonSelected
        m.top.sortID = m.dialog.buttonSelected
        m.dialog.close = true
    end if
end sub

sub UpdateSorting()
    print "... Update Sorting: ";m.top.sortID
    m.global.mainScene.MovieInfoPanel.movieNum = -1
    GetMovies()
end sub
'******************************************************
sub SearchMovies()
    if m.request<>invalid and m.request.state = "run"
        print "...Search Movies: terminate task!"
        m.request.control = "STOP"
    end if

    print "...Search Movies"
    m.global.loading = true
    SetLoadingContent()
    m.request = createObject("roSGNode","GetRequest")
    m.request.uri = m.global.apipath+m.global.apiname+m.global.vodpath+"/vod/ws/Search?sessionId="+ m.global.sessionId+"&q="+m.top.searchText+m.sorting[m.top.sortID].sortString
    m.request.observeField("content","OnMovies")
    m.request.control = "RUN"
end sub
'******************************************************
Function OnKeyEvent(key, press) as Boolean    
    result = false
    if press then
        print "MovieGrid: OnkeyEvent = ";key
        if key = "options"
            ChangeSorting()
            return true
        end if
    end if
    return result
End Function